<?php
/**
 * Created by PhpStorm.
 * User: Ong Chinh
 * Date: 10/12/2016
 * Time: 9:19 AM
 */

if ( ! defined( 'ABSPATH' ) ) {
	die( "You don't have sufficient permission to access this page" );
}

class ArtistasUserSettings {

	public $artistas_custom;

	public function artistas_default_settings () {

		/* Type : text, textarea, spectrum, media */
		return array(
			'facebook'    => array(
				'type'  => 'text',
				'title' => esc_html__( 'Facebook', 'artistas' ),
				'value' => 'https://www.facebook.com/'
			),
			'behance'     => array(
				'type'  => 'text',
				'title' => esc_html__( 'Behance', 'artistas' ),
				'value' => 'https://www.behance.net/'
			),
			'dribbble'    => array(
				'type'  => 'text',
				'title' => esc_html__( 'Dribbble', 'artistas' ),
				'value' => ''
			),
			'flickr'      => array(
				'type'  => 'text',
				'title' => esc_html__( 'Flickr', 'artistas' ),
				'value' => 'https://plus.google.com/'
			),
			'google_plus' => array(
				'type'  => 'text',
				'title' => esc_html__( 'Google Plus', 'artistas' ),
				'value' => ''
			),
			'instagram'   => array(
				'type'  => 'text',
				'title' => esc_html__( 'Instagram', 'artistas' ),
				'value' => ''
			),
			'linkedin'    => array(
				'type'  => 'text',
				'title' => esc_html__( 'Linkedin', 'artistas' ),
				'value' => ''
			),
			'mail'        => array(
				'type'  => 'text',
				'title' => esc_html__( 'Mail', 'artistas' ),
				'value' => ''
			),
			'pinterest'   => array(
				'type'  => 'text',
				'title' => esc_html__( 'Pinterest', 'artistas' ),
				'value' => ''
			),
			'skype'       => array(
				'type'  => 'text',
				'title' => esc_html__( 'Skype', 'artistas' ),
				'value' => ''
			),
			'tumblr'      => array(
				'type'  => 'text',
				'title' => esc_html__( 'Tumblr', 'artistas' ),
				'value' => ''
			),
			'twitter'     => array(
				'type'  => 'text',
				'title' => esc_html__( 'Twitter', 'artistas' ),
				'value' => 'http://twitter.com/'
			),
			'vimeo'       => array(
				'type'  => 'text',
				'title' => esc_html__( 'Vimeo', 'artistas' ),
				'value' => ''
			),
			'yahoo'       => array(
				'type'  => 'text',
				'title' => esc_html__( 'Yahoo', 'artistas' ),
				'value' => ''
			)
		);
	}

	public function __construct () {
		$this->artistas_custom = $this->artistas_default_settings();

		add_action( 'show_user_profile', array( $this, 'artistas_add_field' ) );
		add_action( 'edit_user_profile', array( $this, 'artistas_add_field' ) );
		add_action( 'personal_options_update', array( $this, 'artistas_save' ) );
		add_action( 'edit_user_profile_update', array( $this, 'artistas_save' ) );
	}

	public function artistas_get_data ( $user ) {
		$user_id   = $user->ID;
		$user_meta = get_user_meta( $user_id, 'artistas_user_meta', true );
		if ( empty( $user_meta ) ) {
			$user_meta = array();
			foreach ( $this->artistas_custom as $key => $item ) {
				$user_meta[ $key ] = $item['value'];
			}
			update_user_meta( $user_id, 'artistas_user_meta', $user_meta );
		}

	}

	public function artistas_add_field ( $user ) {
		$this->artistas_get_data( $user );
		$user_meta = get_user_meta( $user->ID, 'artistas_user_meta', true );
		?>
		<h3><?php esc_html_e( 'Additional Information', 'artistas' ); ?></h3>
		<table class="form-table">
			<?php
			foreach ( $this->artistas_custom as $key => $settings ) :
				$function = 'artistas_render_' . $settings['type'];
				call_user_func( array( $this, $function ), $key, $settings, $user_meta[ $key ] );
			endforeach;
			?>
		</table>
		<?php
	}

	public function artistas_render_text ( $key = '', $settings = '', $value = '' ) {
		?>
		<tr class="artistas-<?php echo esc_attr( $key ); ?>">
			<th>
				<label for="artistas_field_<?php echo esc_attr( $key ) ?>"><?php echo esc_attr( $settings['title'] ); ?></label>
			<td>
				<div class="wrap-setting-text">
					<input id="artistas_field_<?php echo esc_attr( $key ) ?>" type="text" name="artistas_user_meta[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $value ); ?>" />
				</div>
			</td>
			</th>
		</tr>
		<?php
	}

	public function artistas_render_textarea ( $key = '', $settings = '', $value = '' ) {
		?>
		<tr class="artistas-<?php echo esc_attr( $key ); ?>">
			<th>
				<label for="artistas_field_<?php echo esc_attr( $key ) ?>"><?php echo esc_attr( $settings['title'] ); ?></label>
			<td>
				<div class="wrap-setting-textarea">
					<textarea name="artistas_user_meta[<?php echo esc_attr( $key ); ?>]" id="artistas_field_<?php echo esc_attr( $key ) ?>"><?php echo esc_attr( $value ); ?></textarea>
				</div>
				<?php
				if ( ! empty( $settings['description'] ) ) {
					?>
					<p class="description">
						<?php echo wp_kses_post( $settings['description'] ); ?>
					</p>
					<?php
				}
				?>
			</td>
			</th>
		</tr>
		<?php
	}

	public function artistas_render_media ( $key = '', $settings = '', $value = '' ) {
		if ( empty( $settings['image_size'] ) ) {
			$settings['image_size'] = 'thumbnail';
		}
		?>
		<tr class="artistas-<?php echo esc_attr( $key ); ?>">
			<th>
				<label for="artistas_field_<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $settings['title'] ); ?></label>
			<td>
				<div class="wrap-media">
					<div class="artistas-upload" data-parent=".artistas-<?php echo esc_attr( $key ); ?> .artistas-img-container" data-multiple="false" data-image-size="<?php echo esc_attr( $settings['image_size'] ); ?>">
						<input class="kd-media-value" type="hidden" />
						<input id="artistas_field_<?php echo esc_attr( $key ); ?>" class="artistas-media-input" type="text" name="artistas_user_meta[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $value ); ?>" />
						<a href="#" class="button kd-button artistas-btn-upload"><?php esc_html_e( 'Upload', 'artistas' ); ?></a>
						<div class="artistas-img-container">
							<?php
							if ( $value != '' ) :
								?>
								<ul class="list-kd-image-media">
									<li class="kd-image">
										<img src="<?php echo esc_url( $value ); ?>" alt="<?php esc_attr( $settings['title'] ); ?>" />
										<div class="kd-control-wrap">
											<i class="kd-edit dashicons dashicons-edit"></i>
											<i class="kd-close dashicons dashicons-no-alt"></i>
										</div>
									</li>
								</ul>
								<?php
							endif;
							?>
						</div>
					</div>
				</div>
				<?php
				if ( ! empty( $settings['description'] ) ) {
					?>
					<p class="description">
						<?php echo wp_kses_post( $settings['description'] ); ?>
					</p>
					<?php
				}
				?>
			</td>
			</th>
		</tr>
		<?php
	}

	public function artistas_render_spectrum ( $key = '', $settings = '', $value = '' ) {
		?>
		<tr class="artistas-<?php echo esc_attr( $key ); ?>">
			<th>
				<label for="artistas_field_<?php echo esc_attr( $key ) ?>"><?php echo esc_attr( $settings['title'] ); ?></label>
			<td>
				<div class="wrap-setting-spectrum">
					<input id="artistas_field_<?php echo esc_attr( $key ) ?>" type="text" name="artistas_user_meta[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $value ); ?>" />
				</div>
				<?php
				if ( ! empty( $settings['description'] ) ) {
					?>
					<p class="description">
						<?php echo wp_kses_post( $settings['description'] ); ?>
					</p>
					<?php
				}
				?>
			</td>
			</th>
		</tr>
		<?php
	}

	public function artistas_save ( $user_id ) {
		if ( ! current_user_can( 'edit_user', $user_id ) ) {
			return false;
		}

		if ( isset( $_POST['artistas_user_meta'] ) ) {
			update_user_meta( $user_id, 'artistas_user_meta', $_POST['artistas_user_meta'] );
		}
	}
}

new ArtistasUserSettings;