<?php
/**
 * Created by PhpStorm.
 * User: MinhMinh
 * Date: 1/8/2017
 * Time: 5:02 AM
 */

require_once( trailingslashit( get_template_directory() ) . 'core/init.php' );

add_action( 'init', 'artistas_theme_setup' );
add_action( 'widgets_init', 'artistas_widget_init' );
add_action( 'wp_enqueue_scripts', 'artistas_enqueue_assets' );
add_action( 'wp_enqueue_scripts', 'artistas_custom_css', 999 );
add_filter( 'wp_title', 'artistas_wp_title' );
add_filter( 'nav_menu_item_title', 'artistas_nav_menu_item_title', 10, 4 );
add_filter( 'wp_head', 'artistas_overwrite_theme_options' );
add_filter( 'wp_head', 'artistas_favicon' );
add_filter( 'mce_buttons', 'artistas_add_next_page_button', 1, 2 );
add_filter( 'comment_form_fields', 'artistas_move_comment_field_to_bottom' );
add_action( 'wp_enqueue_scripts', 'artistas_render_js_inline' );
add_filter( 'excerpt_length', 'artistas_wpse_excerpt_length', 999 );
remove_filter( 'get_the_excerpt', 'wp_trim_excerpt' );
add_filter( 'get_the_excerpt', 'artistas_wpse_custom_wp_trim_excerpt' );
add_filter( 'artistas_image_size', 'artistas_image_size' );

function artistas_theme_setup () {

	global $artistas_theme_options, $artistas_socials_data;

	$artistas_socials_data = array(
		'behance'     => array(
			'title' => esc_html__( 'Behance', 'artistas' ),
			'class' => 'fa fa-behance'
		),
		'dribbble'    => array(
			'title' => esc_html__( 'Dribbble', 'artistas' ),
			'class' => 'fa fa-dribbble'
		),
		'facebook'    => array(
			'title' => esc_html__( 'Facebook', 'artistas' ),
			'class' => 'fa fa-facebook'
		),
		'flickr'      => array(
			'title' => esc_html__( 'Flickr', 'artistas' ),
			'class' => 'fa fa-flickr'
		),
		'google_plus' => array(
			'title' => esc_html__( 'Google Plus', 'artistas' ),
			'class' => 'fa fa-google-plus'
		),
		'instagram'   => array(
			'title' => esc_html__( 'Instagram', 'artistas' ),
			'class' => 'fa fa-instagram'
		),
		'linkedin'    => array(
			'title' => esc_html__( 'Linkedin', 'artistas' ),
			'class' => 'fa fa-linkedin'
		),
		'mail'        => array(
			'title' => esc_html__( 'Mail', 'artistas' ),
			'class' => 'fa fa-envelope'
		),
		'pinterest'   => array(
			'title' => esc_html__( 'Pinterest', 'artistas' ),
			'class' => 'fa fa-pinterest'
		),
		'skype'       => array(
			'title' => esc_html__( 'Skype', 'artistas' ),
			'class' => 'fa fa-skype'
		),
		'tumblr'      => array(
			'title' => esc_html__( 'Tumblr', 'artistas' ),
			'class' => 'fa fa-tumblr'
		),
		'twitter'     => array(
			'title' => esc_html__( 'Twitter', 'artistas' ),
			'class' => 'fa fa-twitter'
		),
		'vimeo'       => array(
			'title' => esc_html__( 'Vimeo', 'artistas' ),
			'class' => 'fa fa-vimeo-square'
		),
		'yahoo'       => array(
			'title' => esc_html__( 'Yahoo', 'artistas' ),
			'class' => 'fa fa-yahoo'
		),
		'youtube'     => array(
			'title' => esc_html__( 'Youtube', 'artistas' ),
			'class' => 'fa fa-youtube'
		)
	);

	$artistas_theme_options = artistas_get_theme_options();

	$languages_folder = trailingslashit( get_template_directory_uri() ) . '/languages';
	load_theme_textdomain( 'artistas', $languages_folder );

	/* Insert RSS Feed link */
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );

	/* Post format */
	add_theme_support( 'post-formats', array( 'image', 'gallery', 'audio', 'quote', 'video' ) );

	/* Add post thumbnail */
	add_theme_support( 'post-thumbnails' );

	/* Add title tag */
	add_theme_support( 'title-tag' );

	/* Create menu */
	add_theme_support( 'menus' );
	add_image_size( 'artistas_1200x800', 1200, 800 );
	add_image_size( 'artistas_600x400', 600, 400 );
	register_nav_menu( 'artistas-main-menu', esc_html__( 'Artistas Main Menu', 'artistas' ) );

	$GLOBALS['content_width'] = 1200;
}

function artistas_get_theme_options () {
	$artistas_theme_options = (array)get_option( 'artistas_theme_options' );
	$artistas_default       = array();
	foreach ( ArtistasThemeOptions::config_options() as $section ) {
		foreach ( $section['fields'] as $setting ) {

			if ( isset( $setting['default'] ) ) {
				$artistas_default[ $setting['id'] ] = $setting['default'];
			} else {
				$artistas_default[ $setting['id'] ] = '';
			}
		}
	}
	$artistas_theme_options = array_merge( $artistas_default, $artistas_theme_options );

	return $artistas_theme_options;
}

function artistas_widget_init () {

	/* Create sidebars */
	$artistas_main_sidebar = array(
		'name'          => esc_html__( 'Artistas Main Sidebar', 'artistas' ),
		'id'            => 'artistas-main-sidebar',
		'description'   => esc_html__( 'Main sidebar for theme Artistas', 'artistas' ),
		'class'         => 'artistas-main-sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>'
	);
	$artistas_left_sidebar = array(
		'name'          => esc_html__( 'Artistas Left Sidebar', 'artistas' ),
		'id'            => 'artistas-left-sidebar',
		'description'   => esc_html__( 'The sidebar is set in the left of site', 'artistas' ),
		'class'         => 'artistas-left-sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>'
	);

	register_sidebar( $artistas_main_sidebar );
	register_sidebar( $artistas_left_sidebar );
}

function artistas_enqueue_assets () {

	wp_register_style( 'fontawesome', trailingslashit( get_template_directory_uri() ) . 'assets/css/libs/font-awesome.min.css', '', null, 'all' );
	wp_register_style( 'owlcarousel', trailingslashit( get_template_directory_uri() ) . 'assets/css/libs/owl.carousel.css', '', null, 'all' );
	wp_register_style( 'artistas-styles', trailingslashit( get_template_directory_uri() ) . 'assets/css/style.css', '', null, 'all' );

	wp_register_script( 'owlcarousel', trailingslashit( get_template_directory_uri() ) . 'assets/js/libs/owl.carousel.min.js', array( 'jquery' ), null, true );
	wp_register_script( 'masonry', trailingslashit( get_template_directory_uri() ) . 'assets/js/libs/masonry.min.js', array( 'jquery' ), null, true );
	wp_register_script( 'artistas-scripts', trailingslashit( get_template_directory_uri() ) . 'assets/js/scripts.js', array( 'jquery' ), null, true );

	if ( ! wp_style_is( 'fontawesome' ) ) {
		wp_enqueue_style( 'fontawesome' );
	}
	if ( ! wp_style_is( 'owlcarousel' ) ) {
		wp_enqueue_style( 'owlcarousel' );
		wp_enqueue_script( 'owlcarousel' );
	}
	wp_enqueue_style( 'artistas-styles' );
	wp_enqueue_script( 'masonry' );
	wp_enqueue_script( 'artistas-scripts' );
	if ( is_singular() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/* Google Font Default Of Template */
	$query_args = array(
		'family' => urlencode( 'Lato:400,700|PT Sans:400,700|Josefin Sans' ),
		'subset' => 'latin,latin-ext'
	);

	wp_register_style( 'google-fonts', add_query_arg( $query_args, "//fonts.googleapis.com/css" ), array(), null );
	wp_enqueue_style( 'google-fonts' );
}

function artistas_custom_css () {
	/* Add Custom Google Font */
	global $artistas_theme_options,
	       $artistas_elements;

	$artistas_elements = array(
		'body'          => 'body',
		'menu'          => '.menu-list, .sub-menu',
		'title'         => '.title, .widget-title, .kd-about h2.title, .widget .title',
		'logo'          => '#header .wrap-logo .logo a',
		'slogan'        => '#header.wrap-logo .slogan',
		'footer_logo'   => '#footer .wrap-logo .logo a',
		'footer_slogan' => '#footer .wrap-logo .slogan'
	);
	$fonts             = array();
	foreach ( $artistas_elements as $font ) {

		$font .= '_font';
		if ( ! empty( $artistas_theme_options[ $font ] ) && is_array( $artistas_theme_options[ $font ] ) ) {
			$google_font = $artistas_theme_options[ $font ];
			$family      = '';

			if ( ! empty( $google_font['font-family'] ) && ! empty( $google_font['google'] ) && $google_font['google'] === 'true' ) {
				$family .= $google_font['font-family'];

				if ( ! empty( $google_font['font-weight'] ) ) {
					$family .= ':' . $google_font['font-weight'];

					if ( ! empty( $google_font['font-style'] ) ) {
						$family .= $google_font['font-style'];
					}
				}
			}

			if ( ! empty( $family ) && ! in_array( $family, $fonts ) ) {
				$fonts[] = $family;
			}
		}
	}

	if ( ! empty( $fonts ) ) {
		$fonts = implode( '|', $fonts );
		$fonts = array(
			'family' => urlencode( $fonts ),
			'subset' => 'latin,latin-ext'
		);
		wp_register_style( 'artistas-add-google-fonts', add_query_arg( $fonts, "//fonts.googleapis.com/css" ), array(), null );
		wp_enqueue_style( 'artistas-add-google-fonts' );
	}

	/* Add custom css */
	$custom_css = '';
	if ( ! empty( $artistas_theme_options['custom_css'] ) ) {
		$custom_css .= ' ' . esc_attr( $artistas_theme_options['custom_css'] );
	}

	// Element settings font
	$custom_css .= artistas_custom_font_for_elements( $custom_css );
	if ( ! empty( $custom_css ) ) {
		wp_add_inline_style( 'artistas-styles', $custom_css );
	}
}

function artistas_wp_title ( $title, $sep ) {
	if ( ! function_exists( '_wp_render_title_tag' ) ) {
		global $paged, $page;
		if ( is_feed() ) {
			return $title;
		}
		// Add the site name.
		$title .= get_bloginfo( 'name' );

		// Add the site description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title = "$title $sep $site_description";
		}
		// Add a page number if necessary.
		if ( $paged >= 2 || $page >= 2 ) {
			$title = "$title $sep " . sprintf( esc_html__( 'Page %s', 'artistas' ), max( $paged, $page ) );
		}
	}

	return $title;
}

function artistas_nav_menu_item_title ( $title, $item, $args, $depth ) {

	foreach ( $item->classes as $class ) {
		if ( $class === 'menu-item-has-children' ) {
			$title .= '<span class="menu-expand"></span>';

			return $title;
		}
	}

	return $title;
}

function artistas_overwrite_theme_options () {
	global $artistas_theme_options;

	foreach ( $artistas_theme_options as $key => $value ) {

		if ( isset( $_GET[ $key ] ) ) {
			$artistas_theme_options[ $key ] = $_GET[ $key ];
		}
	}
}

function artistas_favicon () {

	global $artistas_theme_options;

	if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) {
		if ( ! empty( $artistas_theme_options['favicon'] ) && ! empty( $artistas_theme_options['favicon']['id'] ) ) {

			$favicon = wp_get_attachment_image_src( $artistas_theme_options['favicon']['id'], 'full' );
			if ( ! empty( $favicon ) ) {
				?>
				<link rel="icon" type="image/x-icon" href="<?php echo esc_url( $favicon[0] ); ?>">
				<?php
			}
		}
	}
}

function artistas_add_next_page_button ( $buttons, $id ) {
	if ( 'content' != $id ) {
		return $buttons;
	}

	array_splice( $buttons, 13, 0, 'wp_page' );

	return $buttons;
}

function artistas_move_comment_field_to_bottom ( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;

	return $fields;
}

function artistas_render_js_inline () {
	global $artistas_theme_options;
	if ( ! empty( $artistas_theme_options['custom_js'] ) ) {
		wp_add_inline_script( 'artistas-scripts', $artistas_theme_options['custom_js'] );
	}
}

function artistas_wpse_allowedtags () {
	// Add custom tags to this string
	return '<script>,<style>,<br>,<em>,<b>, <span>, <strong>,<i>,<ul>,<ol>,<li>,<a>,<p>,<img>,<video>,<audio>';
}

function artistas_wpse_custom_wp_trim_excerpt ( $wpse_excerpt ) {
	$raw_excerpt = $wpse_excerpt;
	if ( '' == $wpse_excerpt ) {

		$wpse_excerpt = get_the_content( '' );
		$wpse_excerpt = strip_shortcodes( $wpse_excerpt );
		$wpse_excerpt = apply_filters( 'the_content', $wpse_excerpt );
		$wpse_excerpt = str_replace( ']]>', ']]&gt;', $wpse_excerpt );
		$wpse_excerpt = strip_tags( $wpse_excerpt, artistas_wpse_allowedtags() ); /*IF you need to allow just certain tags. Delete if all tags are allowed */

		//Set the excerpt word count and only break after sentence is complete.
		$excerpt_word_count = 75;
		$excerpt_length     = apply_filters( 'excerpt_length', $excerpt_word_count );
		$tokens             = array();
		$excerptOutput      = '';
		$count              = 0;

		// Divide the string into tokens; HTML tags, or words, followed by any whitespace
		preg_match_all( '/(<[^>]+>|[^<>\s]+)\s*/u', $wpse_excerpt, $tokens );

		foreach ( $tokens[0] as $token ) {

			if ( $count >= $excerpt_length && preg_match( '/[\,\;\?\.\!]\s*$/uS', $token ) ) {
				// Limit reached, continue until , ; ? . or ! occur at the end
				$excerptOutput .= trim( $token );
				break;
			}

			// Add words to complete sentence
			$count ++;

			// Append what's left of the token
			$excerptOutput .= $token;
		}

		$wpse_excerpt = trim( force_balance_tags( $excerptOutput ) );

		$excerpt_end  = '';
		$excerpt_more = apply_filters( 'artistas_excerpt_more', ' ' . $excerpt_end );

		//$pos = strrpos($wpse_excerpt, '</');
		//if ($pos !== false)
		// Inside last HTML tag
		//$wpse_excerpt = substr_replace($wpse_excerpt, $excerpt_end, $pos, 0); /* Add read more next to last word */
		//else
		// After the content
		$wpse_excerpt .= $excerpt_more; /*Add read more in new paragraph */

		return $wpse_excerpt;

	}

	return apply_filters( 'artistas_wpse_custom_wp_trim_excerpt', $wpse_excerpt, $raw_excerpt );
}

function artistas_wpse_excerpt_length ( $length ) {
	global $artistas_theme_options;

	if ( ! empty( $artistas_theme_options['home_excerpt_limit'] ) ) {
		return absint( $artistas_theme_options['home_excerpt_limit'] );
	}

	return 250;
}

function artistas_image_size ( $image_size ) {

	if ( empty( $image_size ) ) {
		return $image_size;
	}

	$useragent = $_SERVER['HTTP_USER_AGENT'];
	$match     = preg_match( '/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i', $useragent ) || preg_match( '/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i', substr( $useragent, 0, 4 ) );

	if ( ! $match ) {
		return $image_size;
	}
	if ( $image_size == 'artistas_1200x800' || $image_size == 'large' ) {
		return 'artistas_600x400';
	}

	return $image_size;

}

function artistas_preloader () {
	global $artistas_theme_options;

	if ( ! empty( $artistas_theme_options['preloader'] ) ) {
		?>
		<!-- Preloader -->
		<div class="preloader">
			<?php
			switch ( $artistas_theme_options['preloader'] ) {
				case 'preloader_1':
					?>
					<div class="loader">
						<span></span>
						<span></span>
						<span></span>
						<span></span>
					</div>
					<?php
					break;

				case 'preloader_2':
					?>
					<div class="cont">
						<div class="line square"></div>
						<div class="line square2"></div>
						<div class="line square3"></div>
						<div class="line square4"></div>
					</div>
					<?php
					break;
			}
			?>
		</div>
		<!-- End Preloader -->
		<?php
	}
}

function artistas_header () {

	global $artistas_theme_options;

	$show_sidebar_second = 'kd-not-show';

	if ( ! empty( $artistas_theme_options['show_sidebar_second'] ) && $artistas_theme_options['show_sidebar_second'] === '1' && is_active_sidebar( 'artistas-left-sidebar' ) ) {
		$show_sidebar_second = '';
	}
	?>
	<!-- Header -->
	<header id="header">

		<!-- Fixed Top -->
		<div class="header navbar-fixed-top">
			<div class="kd-container">

				<!-- Header Left Box -->
				<div class="header-left <?php echo esc_attr( $show_sidebar_second ); ?>">
					<ul>
						<li></li>
						<li></li>
						<li></li>
						<li></li>
					</ul>
				</div>
				<!-- End Header Left Box -->

				<?php artistas_the_menu( '', true ); ?>
				<?php artistas_header_right_box( $artistas_theme_options ); ?>

			</div>
		</div>
		<!-- End Fixed Top -->

		<?php artistas_the_logo( $artistas_theme_options ); ?>
	</header>
	<!-- End Header -->
	<?php

}

function artistas_the_menu ( $class = '', $menu_mobile = false ) {

	if ( has_nav_menu( 'artistas-main-menu' ) ) {

		if ( $menu_mobile ) {

			?>
			<!--Menu Mobile -->
			<div class="menu-mobile">
				<span class="item item-1"></span>
				<span class="item item-2"></span>
				<span class="item item-3"></span>
			</div>
			<!--Menu Mobile -->
			<?php
		}
		?>

		<!-- Navigation -->
		<nav class="navigation <?php echo esc_attr( $class ); ?>">
			<?php
			$id = 'artistas-main-menu';
			if ( ! empty( $class ) ) {
				$id .= '-' . $class;
			}
			wp_nav_menu( array(
				'theme_location'  => 'artistas-main-menu',
				'container'       => '',
				'container_class' => '',
				'menu_id'         => esc_attr( $id ),
				'menu_class'      => 'menu menu-list',
				'items_wrap'      => '<ul id="%1$s" class="%2$s">%3$s</ul>',
			) );
			?>
		</nav>
		<!-- End Navigation -->
		<?php
	}
}

function artistas_header_right_box ( $artistas_theme_options ) {

	if ( ( empty( $artistas_theme_options['show_search'] ) || $artistas_theme_options['show_search'] !== '1' ) &&
	     ( empty( $artistas_theme_options['show_socials'] ) || $artistas_theme_options['show_socials'] !== '1' )
	) {
		return;
	}
	?>
	<!-- Header Right Box -->
	<div class="header-right">
		<div class="top-social-icons">
			<div class="list-socials">
				<?php artistas_the_list_socials( $artistas_theme_options, '', '' ); ?>

				<?php
				if ( ! empty( $artistas_theme_options['show_search'] ) && $artistas_theme_options['show_search'] === '1' ) {
					?>
					<a href="#" title="Search" class="kd-btn-search">
						<i class="fa fa-search"></i>
					</a>
					<?php
				}
				?>
			</div>

			<?php
			if ( ! empty( $artistas_theme_options['show_search'] ) && $artistas_theme_options['show_search'] === '1' ) {
				?>
				<div class="box-search">
					<?php echo get_search_form(); ?>
				</div>
				<?php
			}
			?>
		</div>
	</div>
	<!-- End Header Right Box -->
	<?php
}

function artistas_the_list_socials ( $artistas_theme_options, $before_html = '<div class="list-socials">', $after_html = '</div>' ) {

	if ( ! empty( $artistas_theme_options['show_socials'] ) && $artistas_theme_options['show_socials'] === '1' ) {

		global $artistas_socials_data;

		echo wp_kses_post( $before_html );

		foreach ( $artistas_socials_data as $key => $social ) {

			if ( ! empty( $artistas_theme_options[ $key ] ) ) {
				?>
				<a href="<?php echo esc_url( $artistas_theme_options[ $key ] ); ?>" title="<?php echo esc_attr( $social['title'] ); ?>">
					<i class="<?php echo esc_attr( $social['class'] ); ?>"></i>
				</a>
				<?php
			}
		}

		echo wp_kses_post( $after_html );

	}
}

function artistas_the_logo ( $artistas_theme_options, $logo = 'logo', $slogan = 'slogan' ) {
	if ( isset( $artistas_theme_options[ $logo . '_type' ] ) && $artistas_theme_options[ $logo . '_type' ] === 'image' ) {
		if ( ! empty( $artistas_theme_options[ $logo . '_image' ] ) && ! empty( $artistas_theme_options[ $logo . '_image' ]['id'] ) ) {
			$logo_src = wp_get_attachment_image_src( $artistas_theme_options[ $logo . '_image' ]['id'], 'large' );

			if ( ! empty( $logo_src ) ) {
				$logo_src = $logo_src[0];
			}
		} else if ( ! empty( $artistas_theme_options[ $logo . '_image' ] ) && ! empty( $artistas_theme_options[ $logo . '_image' ]['src'] ) ) {
			$logo_src = $artistas_theme_options[ $logo . '_image' ]['src'];
		}

		if (!empty($logo_src)) {
			?>
			<!-- Logo -->
			<div class="wrap-logo logo-image">
				<div class="kd-container">
					<div class="kd-row">
						<div class="logo">
							<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
								<img src="<?php echo esc_url($logo_src); ?>" alt="<?php bloginfo('name'); ?>">
							</a>
						</div>
					</div>
				</div>
			</div>
			<!-- End Logo -->
			<?php
		}
		return;
	}
	if ( empty( $artistas_theme_options[ $logo ] ) && empty( $slogan ) ) {
		return;
	}
	?>
	<!-- Logo -->
	<div class="wrap-logo">
		<div class="kd-container">
			<div class="kd-row">
				<?php
				if ( ! empty( $artistas_theme_options[ $logo ] ) ) {
					?>
					<h1 class="logo">
						<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo wp_kses_post( $artistas_theme_options[ $logo ] ); ?></a>
					</h1>
					<?php
				}
				if ( ! empty( $artistas_theme_options[ $slogan ] ) ) {
					?>
					<h5 class="slogan">
						<?php echo wp_kses_post( $artistas_theme_options[ $slogan ] ); ?>
					</h5>
					<?php
				}

				?>
			</div>
		</div>
	</div>
	<!-- End Logo -->
	<?php

}

function artistas_left_sidebar () {

	global $artistas_theme_options;

	?>
	<div class="sidebar-left">

		<!--Menu Responsive -->
		<?php artistas_the_menu( 'navigation-small' ); ?>
		<!--Menu Responsive -->

		<?php
		if ( ! empty( $artistas_theme_options['show_sidebar_second'] ) && $artistas_theme_options['show_sidebar_second'] === '1' ) {
			dynamic_sidebar( 'artistas-left-sidebar' );
		}
		?>

	</div>
	<!-- Sidebar Left -->
	<div class="overlay-body"></div>
	<!-- Sidebar Left -->
	<?php
}

function artistas_featured_slider () {

	if ( ! is_home() && ! is_page_template() ) {
		return false;
	}

	global $artistas_theme_options;

	if ( ! empty( $artistas_theme_options['featured_number_post'] ) && (int)$artistas_theme_options['featured_number_post'] ) {

		$featured_number_posts = (int)$artistas_theme_options['featured_number_post'];
		$arg_query             = array(
			'post_type'           => 'post',
			'posts_per_page'      => $featured_number_posts,
			'suppress_filters'    => true,
			'ignore_sticky_posts' => false
		);
		if ( ! empty( $artistas_theme_options['featured_category'] ) ) {
			$arg_query['category_name'] = $artistas_theme_options['featured_category'];
		}
		if ( ! empty( $artistas_theme_options['featured_tags'] ) ) {
			$arg_query['tag'] = $artistas_theme_options['featured_tags'];
		}
		if ( ! empty( $artistas_theme_options['featured_order'] ) ) {
			$arg_query['order'] = $artistas_theme_options['featured_order'];
		}
		if ( ! empty( $artistas_theme_options['featured_order_by'] ) ) {
			$arg_query['orderby'] = $artistas_theme_options['featured_order_by'];
		}

		query_posts( $arg_query );

		if ( have_posts() ) {
			global $artistas_featured_posts_id;
			$artistas_featured_posts_id = array();
			?>
			<!-- Featured Slider -->
			<div id="featured-slider" class="featured-slider">
				<?php
				while ( have_posts() ) {
					the_post();
					$artistas_featured_posts_id[] = get_the_ID();

					?>
					<div id="post-<?php the_ID(); ?>" class="item">
						<?php
						$image = artistas_get_image_thumbnail( 'artistas_1200x800' );
						if ( $image ) {
							?>
							<div class="image" style="background-image: url(<?php echo esc_url( $image ); ?>)">
								<img src="<?php echo esc_url( $image ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
							</div>
							<?php
						} else {
							?>
							<div class="image"></div>
							<?php
						}
						?>
						<div class="content">
							<div class="post-cat">
								<?php echo get_the_category_list(); ?>
							</div>
							<h2 class="title">
								<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
							</h2>
						</div>
					</div>

					<?php
				}
				?>
			</div>
			<!-- End Featured Slider -->
			<?php
		}
		wp_reset_query();
	}

}

function artistas_get_image_thumbnail ( $image_size = 'thumbnail', $post_id = '' ) {

	$image = '';

	$image_size = apply_filters( 'artistas_image_size', $image_size, $post_id );

	if ( empty( $post_id ) ) {
		$post_id = get_the_ID();
	}
	if ( has_post_thumbnail( $post_id ) ) {
		$attachment_id = get_post_thumbnail_id( $post_id );
		$image         = wp_get_attachment_image_src( $attachment_id, $image_size );

		if ( $image ) {
			$image = $image[0];
		}
	}

	return $image;
}

function artistas_footer () {

	global $artistas_theme_options;
	?>
	<!--Footer -->
	<footer id="footer" class="footer">
		<?php
		artistas_footer_slider( $artistas_theme_options );
		artistas_footer_info( $artistas_theme_options );
		?>
	</footer>
	<!--End Footer -->
	<?php
}

function artistas_footer_info ( $artistas_theme_options ) {

	?>
	<div class="footer-info">
		<?php
		artistas_the_logo( $artistas_theme_options, 'footer_logo', 'footer_slogan' );

		if ( ! empty( $artistas_theme_options['footer_socials'] ) && $artistas_theme_options['footer_socials'] === '1' ) {
			artistas_the_list_socials( $artistas_theme_options, '<div class="kd-container"><div class="kd-row"><div class="list-socials">', '</div></div></div>' );
		}

		?>

	</div>

	<?php
	if ( ! empty( $artistas_theme_options['footer_bottom'] ) && $artistas_theme_options['footer_bottom'] === '1' ) {
		?>
		<div class="copyright">
			<div class="kd-container">
				<div class="kd-row clearfix">
					<div class="kd-col">
						<?php
						if ( ! empty( $artistas_theme_options['footer_copyright'] ) ) {
							?>
							<div class="copyright-text">
								<?php echo wp_kses_post( $artistas_theme_options['footer_copyright'] ); ?>
							</div>
							<?php
						}
						if ( ! empty( $artistas_theme_options['footer_back_to_top'] ) ) {
							?>
							<div class="back-to-top">
								<?php echo wp_kses_post( $artistas_theme_options['footer_back_to_top'] ); ?>
							</div>
							<?php
						}
						?>
					</div>
				</div>
			</div>
		</div>
		<?php

		if ( ! empty( $artistas_theme_options['footer_back_to_top'] ) ) {
			?>
			<div class="btn-back-to-top"></div>
			<?php
		}
	}
}

function artistas_footer_slider ( $artistas_theme_options ) {

	if ( ! empty( $artistas_theme_options['footer_slider'] ) ) {

		?>
		<div class="footer-instagram">
			<?php
			if ( ! empty( $artistas_theme_options['footer_slider_text'] ) ) {
				?>
				<div class="instagram-text">
					<div class="kd-container">
						<div class="kd-row">
							<?php echo wp_kses_post( $artistas_theme_options['footer_slider_text'] ); ?>
						</div>
					</div>
				</div>
				<?php
			}

			$function = 'artistas_get_image_from_' . $artistas_theme_options['footer_slider'];
			$images   = array();

			if ( is_callable( $function ) ) {
				$images = call_user_func( $function, $artistas_theme_options );
			}

			if ( ! empty( $images ) ) {
				?>
				<ul class="instagram-feeds clearfix">
					<?php
					foreach ( $images as $image ) {
						?>
						<li class="instagram-item">
							<a href="<?php echo esc_url( $image['url'] ) ?>" style="background-image:url(<?php echo esc_url( $image['image'] ); ?>)">
								<img src="<?php echo esc_url( $image['image'] ); ?>" alt="<?php echo esc_attr( $image['text'] ); ?>">
							</a>
						</li>
						<?php
					}

					?>
				</ul>
				<?php
			}

			?>
		</div>
		<?php
	}
}

function artistas_get_image_from_instagram ( $artistas_theme_options ) {

	$return = array();

	if ( ! empty( $artistas_theme_options['instagram_access_token'] ) ) {

		$instagram    = explode( '.', $artistas_theme_options['instagram_access_token'] );
		$instagram_id = '';

		if ( is_array( $instagram ) && ! empty( $instagram ) ) {
			$instagram_id = $instagram[0];
		}
		if ( empty( $instagram_id ) ) {
			return array();
		}
		$url      = 'https://api.instagram.com/v1/users/' . esc_attr( $instagram_id ) . '/media/recent?access_token=' . esc_attr( $artistas_theme_options['instagram_access_token'] ) . '&count=12';
		$response = wp_remote_get( esc_url_raw( $url ), array( 'decompress' => false ) );

		if ( ! is_wp_error( $response ) ) {
			$response = wp_remote_retrieve_body( $response );
			$response = json_decode( $response, true );

			if ( ! empty( $response['data'] ) ) {
				for ( $i = 0; $i < 12; $i ++ ) {
					if ( ! empty( $response['data'][ $i ] ) ) {
						$return[] = array(
							'url'   => $response['data'][ $i ]['link'],
							'image' => $response['data'][ $i ]['images']['low_resolution']['url'],
							'text'  => $response['data'][ $i ]['caption']['text']
						);
					}
				}
			}
		}
	}

	return $return;
}

function artistas_get_image_from_flickr ( $artistas_theme_options ) {

	$return = array();

	if ( ! empty( $artistas_theme_options['flickr_id'] ) ) {

		$api_key  = '527717749cea38de23ef84c73acfeef8';
		$url      = 'https://api.flickr.com/services/rest/?method=flickr.people.getPhotos&api_key=' . esc_attr( $api_key ) . '&user_id=' . esc_attr( $artistas_theme_options['flickr_id'] ) . '&per_page=12&format=json&nojsoncallback=1';
		$response = wp_remote_get( esc_url_raw( $url ), array( 'decompress' => false ) );

		if ( ! is_wp_error( $response ) ) {

			$response = wp_remote_retrieve_body( $response );
			$response = json_decode( $response, true );

			if ( ! empty( $response['photos']['photo'] ) ) {
				foreach ( $response['photos']['photo'] as $index => $photo ) {
					$return[] = array(
						'url'   => 'https://www.flickr.com/photos/' . esc_attr( $artistas_theme_options['flickr_id'] ) . '/' . $photo['id'],
						'image' => 'http://farm' . $photo['farm'] . '.staticflickr.com/' . $photo['server'] . '/' . $photo['id'] . '_' . $photo['secret'] . '_z.jpg',
						'text'  => ''
					);
				}
			}
		}
	}

	return $return;

}

function artistas_posts ( $extend_query = array() ) {

	global $artistas_theme_options;

	$function = 'artistas_render_posts_';

	if ( ! empty( $artistas_theme_options['home_style'] ) ) {
		$function .= $artistas_theme_options['home_style'];
	} else {
		$function .= 'standard';
	}

	?>
	<!-- Posts -->
	<div class="wrapper-content clearfix" <?php
	if ( ! empty( $artistas_theme_options['home_sidebar'] ) ) {
		echo 'data-sidebar="' . esc_attr( $artistas_theme_options['home_sidebar'] ) . '"';
	}
	?>>
		<div class="kd-container">
			<div class="kd-row">
				<div class="wrapper-posts">

					<div class="kd-col">

						<?php artistas_archive_detail( $artistas_theme_options, $extend_query ); ?>

						<div class="blog-posts">
							<?php
							if ( is_callable( $function ) && have_posts() ) {
								call_user_func( $function, $artistas_theme_options );
							}
							?>
						</div>

						<?php artistas_pagination( $artistas_theme_options ); ?>
					</div>

				</div>

				<?php
				if ( ! empty( $artistas_theme_options['home_sidebar'] ) && $artistas_theme_options['home_sidebar'] != 'no-sidebar' ) {
					get_sidebar();
				}
				?>
			</div>
		</div>
	</div>
	<!-- End Posts -->
	<?php
}

function artistas_pagination ( $settings ) {

	$pagination = 'button';

	if ( ! empty( $settings['home_pagination'] ) ) {
		$pagination = $settings['home_pagination'];
	}

	if ( $pagination == 'number' ) {
		global $wp_query;

		$pages = paginate_links( array(
			'format'             => '?paged=%#%',
			'prev_text'          => '<i class="fa fa-angle-double-left"></i>',
			'next_text'          => '<i class="fa fa-angle-double-right"></i>',
			'before_page_number' => '',
			'after_page_number'  => '',
			'show_all'           => false,
			'type'               => 'array',
			'total'              => $wp_query->max_num_pages,
		) );

		if ( is_array( $pages ) ) {
			$paged = ( get_query_var( 'paged' ) == 0 ) ? 1 : get_query_var( 'paged' );

			?>
			<!-- Pagination -->
			<div class="pagination-wrap">
				<ul class="pagination">
					<?php
					foreach ( $pages as $key => $page ) {
						if ( $paged == 1 ) {
							if ( $key == ( $paged - 1 ) ) {
								echo "<li><span class='page-numbers current'>$paged</span></li>";
							} else {
								echo "<li>$page</li>";
							}
						} else {
							if ( $key == $paged ) {
								echo "<li><span class='page-numbers current'>$paged</span></li>";
							} else {
								echo "<li>$page</li>";
							}
						}
					}
					?>
				</ul>
			</div>
			<!-- End Pagination -->
			<?php
		}
	} else if ( $pagination == 'button' ) {

		$text_next = $text_prev = '';

		if ( ! empty( $settings['home_text_new_posts'] ) ) {
			$text_next = $settings['home_text_new_posts'];
		}
		if ( ! empty( $settings['home_text_older_posts'] ) ) {
			$text_prev = $settings['home_text_older_posts'];
		}
		$next_button     = get_previous_posts_link( wp_kses_post( $text_next ) );
		$previous_button = get_next_posts_link( wp_kses_post( $text_prev ) );
		$class           = 'kd-navigation';
		$arr             = array( 'grid', 'grid_1st_large' );

		if ( in_array( $settings['home_style'], $arr ) ) {
			$class .= ' margin-top--30';
		}
		if ( ! empty( $next_button ) || ! empty( $previous_button ) ) {
			?>
			<!-- Pagination -->
			<div class="pagination-wrap">
				<div class="<?php echo esc_attr( $class ); ?>">
					<?php
					if ( ! empty( $text_next ) && $next_button ) {
						?>
						<div class="new-post">
							<?php echo wp_kses_post( $next_button ); ?>
						</div>
						<?php
					}

					if ( ! empty( $text_prev ) && $previous_button ) {
						?>
						<div class="old-post">
							<?php echo wp_kses_post( $previous_button ); ?>
						</div>
						<?php
					}
					?>
				</div>
			</div>

			<!-- End Pagination -->
			<?php
		}
	}
}

function artistas_render_posts_standard ( $settings ) {
	while ( have_posts() ) {
		the_post();
		artistas_render_post_standard( $settings );
	}
}

function artistas_render_posts_grid ( $settings ) {
	?>
	<div class="blog-grids">
		<?php
		while ( have_posts() ) {
			the_post();
			artistas_render_post_grid( $settings );
		}
		?>
	</div>
	<?php
}

function artistas_render_posts_list ( $settings ) {
	?>
	<div class="list-layout">
		<?php
		while ( have_posts() ) {
			the_post();
			artistas_render_post_list( $settings );
		}
		?>
	</div>
	<?php
}

function artistas_render_posts_grid_1st_large ( $settings ) {
	the_post();
	artistas_render_post_standard( $settings, ' margin-bottom-30' );
	?>
	<div class="blog-grids">
		<?php
		while ( have_posts() ) {
			the_post();
			artistas_render_post_grid( $settings );
		}
		?>
	</div>
	<?php
}

function artistas_render_posts_list_1st_large ( $settings ) {
	the_post();
	artistas_render_post_standard( $settings, ' margin-bottom-30' );
	?>
	<div class="list-layout">
		<?php
		while ( have_posts() ) {
			the_post();
			artistas_render_post_list( $settings );
		}
		?>
	</div>
	<?php
}

function artistas_render_post_standard ( $settings, $class = '' ) {
	?>
	<div class="post-standard<?php echo esc_attr( $class ); ?>">
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			<?php
			if ( ! empty( $settings['home_thumbnail'] ) && $settings['home_thumbnail'] === '1' ) {
				artistas_thumbnail( 'artistas_1200x800' );
			}
			?>

			<div class="post-content">
				<?php
				if ( ! empty( $settings['home_category'] ) && $settings['home_category'] === '1' ) {
					?>
					<div class="post-cat">
						<?php echo get_the_category_list() ?>
					</div>
					<?php
				}
				?>
				<h2 class="title">
					<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
				</h2>

				<?php
				if ( ( ! empty( $settings['home_date'] ) && $settings['home_date'] === '1' ) ||
				     ( ! empty( $settings['home_author'] ) && $settings['home_author'] === '1' )
				) {
					?>
					<div class="post-detail">
						<?php
						if ( ! empty( $settings['home_date'] ) && $settings['home_date'] === '1' ) {
							artistas_post_date();
						}

						if ( ! empty( $settings['home_author'] ) && $settings['home_author'] === '1' ) {
							artistas_post_author();
						}
						?>
					</div>
					<?php
				}
				?>

				<div class="the-excerpt">
					<?php echo get_the_excerpt(); ?>
				</div>

				<?php
				if ( ! empty( $settings['home_read_more'] ) ) {
					?>
					<div class="read-more-wrap">
						<a href="<?php the_permalink(); ?>" class="read-more"><?php echo wp_kses_post( $settings['home_read_more'] ); ?></a>
					</div>
					<?php
				}

				artistas_footer_post( $settings, 'home_comment_count', 'home_sharing_post' );
				?>
			</div>
		</article>
	</div>
	<?php

}

function artistas_render_post_grid ( $settings ) {
	?>
	<div class="post-grid">
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			<?php
			if ( ! empty( $settings['home_thumbnail'] ) && $settings['home_thumbnail'] === '1' ) {
				artistas_thumbnail( 'artistas_600x400' );
			}
			?>

			<div class="post-content">
				<?php
				if ( ! empty( $settings['home_category'] ) && $settings['home_category'] === '1' ) {
					?>
					<div class="post-cat">
						<?php echo get_the_category_list() ?>
					</div>
					<?php
				}
				?>
				<h2 class="title">
					<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
				</h2>

				<?php
				if ( ( ! empty( $settings['home_date'] ) && $settings['home_date'] === '1' ) ||
				     ( ! empty( $settings['home_author'] ) && $settings['home_author'] === '1' )
				) {
					?>
					<div class="post-detail">
						<?php
						if ( ! empty( $settings['home_date'] ) && $settings['home_date'] === '1' ) {
							artistas_post_date();
						}

						if ( ! empty( $settings['home_author'] ) && $settings['home_author'] === '1' ) {
							artistas_post_author();
						}
						?>
					</div>
					<?php
				}
				?>

				<div class="the-excerpt">
					<?php echo get_the_excerpt(); ?>
				</div>

				<?php
				if ( ! empty( $settings['home_read_more'] ) ) {
					?>
					<div class="read-more-wrap">
						<a href="<?php the_permalink(); ?>" class="read-more"><?php echo wp_kses_post( $settings['home_read_more'] ); ?></a>
					</div>
					<?php
				}

				artistas_footer_post( $settings, 'home_comment_count', 'home_sharing_post' );

				?>
			</div>
		</article>
	</div>
	<?php
}

function artistas_render_post_list ( $settings ) {
	?>
	<div class="post-list">
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			<?php
			if ( ! empty( $settings['home_thumbnail'] ) && $settings['home_thumbnail'] === '1' ) {
				artistas_thumbnail( 'artistas_600x400', true );
			}
			?>

			<div class="post-content">
				<?php
				if ( ! empty( $settings['home_category'] ) && $settings['home_category'] === '1' ) {
					?>
					<div class="post-cat">
						<?php echo get_the_category_list() ?>
					</div>
					<?php
				}
				?>
				<h2 class="title">
					<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
				</h2>

				<?php
				if ( ( ! empty( $settings['home_date'] ) && $settings['home_date'] === '1' ) ||
				     ( ! empty( $settings['home_author'] ) && $settings['home_author'] === '1' )
				) {
					?>
					<div class="post-detail">
						<?php
						if ( ! empty( $settings['home_date'] ) && $settings['home_date'] === '1' ) {
							artistas_post_date();
						}

						if ( ! empty( $settings['home_author'] ) && $settings['home_author'] === '1' ) {
							artistas_post_author();
						}
						?>
					</div>
					<?php
				}
				?>

				<div class="the-excerpt">
					<?php echo get_the_excerpt(); ?>
				</div>

			</div>
		</article>
	</div>
	<?php
}

function artistas_archive_detail ( $settings, $extend_query ) {

	if ( empty( $settings['archive_detail'] ) || $settings['archive_detail'] !== '1' ) {
		return;
	}

	$title = '';

	if ( ! empty( $extend_query['author'] ) ) {

		$author = get_the_author_meta( 'display_name', $extend_query['author'] );
		$title  = esc_html__( 'Posts by ', 'artistas' ) . '<span class="archive-name">' . $author . '</span>';

	}
	if ( ! empty( $extend_query['category_name'] ) ) {

		$category = get_category_by_slug( $extend_query['category_name'] );
		$title    = esc_html__( 'Browse category by ', 'artistas' ) . '<span class="archive-name">' . $category->name . '</span>';

	} else if ( ! empty( $extend_query['tag'] ) ) {

		$tag   = get_term_by( 'slug', $extend_query['tag'], 'post_tag' );
		$title = esc_html__( 'Browse posts tag by ', 'artistas' ) . '<span class="archive-name">' . $tag->name . '</span>';

	} else if ( ! empty( $extend_query['s'] ) ) {

		$title = esc_html__( 'Search results by ', 'artistas' ) . '<span class="archive-name">' . $extend_query['s'] . '</span>';

	} else if ( ! empty( $extend_query['year'] ) ) {

		$title = esc_html__( 'Year: ', 'artistas' ) . '<span class="archive-name">' . $extend_query['year'] . '</span>';

		if ( ! empty( $extend_query['monthnum'] ) ) {

			$month = $GLOBALS['wp_locale']->get_month( $extend_query['monthnum'] );
			$title = esc_html__( 'Month: ', 'artistas' ) . '<span class="archive-name">' . $month . ',' . $extend_query['year'] . '</span>';

			if ( ! empty( $extend_query['day'] ) ) {

				$title = esc_html__( 'Day: ', 'artistas' ) . '<span class="archive-name">' . $extend_query['year'] . '/ ' . $extend_query['monthnum'] . '/ ' . $extend_query['day'] . '</span>';

			}
		}
	} else if ( ! empty( $extend_query['tax_query'] ) ) {

		$post_format = get_post_format();
		$title       = esc_html__( 'Post format: ', 'artistas' ) . '<span class="archive-name">' . wp_kses_post( $post_format ) . '</span>';

	}
	if ( ! empty( $title ) ) {
		?>
		<!-- Archive Detail -->
		<div class="archive-detail">
			<div class="archive-title">
				<?php echo wp_kses_post( $title ); ?>
			</div>
		</div>
		<!-- End Archive Detail -->
		<?php
	}
}

function artistas_archive_external_query () {

	$arg_query = array();

	if ( is_category() ) {

		$category                   = get_term_by( 'name', single_cat_title( '', false ), 'category' );
		$arg_query['category_name'] = $category->slug;

	} else if ( is_author() ) {

		$author              = get_queried_object();
		$arg_query['author'] = $author->ID;

	} else if ( is_tag() ) {

		$tag              = get_term_by( 'name', single_cat_title( '', false ), 'post_tag' );
		$arg_query['tag'] = $tag->slug;

	} else if ( is_date() ) {

		$arg_query['monthnum'] = get_query_var( 'monthnum' );
		$arg_query['year']     = get_query_var( 'year' );
		$arg_query['day']      = get_query_var( 'day' );

	} else if ( is_search() ) {

		$arg_query['s'] = get_search_query();

	} else if ( is_tax( 'post_format' ) ) {

		$post_format = get_post_format();

		if ( ! empty( $post_format ) ) {
			$arg_query['tax_query'] = array(
				array(
					'taxonomy' => 'post_format',
					'field'    => 'slug',
					'terms'    => 'post-format-' . $post_format
				)
			);
		}
	}

	return $arg_query;
}

function artistas_thumbnail ( $image_size = 'thumbnail', $background = false ) {

	$image = artistas_get_image_thumbnail( $image_size );

	if ( empty( $image ) ) {
		return;
	}
	?>

	<!-- Thumbnail -->
	<div class="post-media">
		<a href="<?php the_permalink(); ?>"
			<?php
			if ( $background ) {
				echo 'style="background-image: url(' . esc_url( $image ) . ')"';
			}
			?>
		>
			<img src="<?php echo esc_url( $image ); ?>" alt="<?php the_title(); ?>">
		</a>
	</div>
	<!-- End Thumbnail -->
	<?php
}

function artistas_post_date ( $class = 'date' ) {
	$archive_year  = get_the_time( 'Y' );
	$archive_month = get_the_time( 'm' );

	?>
	<a href="<?php echo esc_url( get_month_link( $archive_year, $archive_month ) ); ?>" class="<?php echo esc_attr( $class ); ?>"><?php echo get_the_date(); ?></a>
	<?php
}

function artistas_post_author () {

	$post        = get_post();
	$author_url  = get_author_posts_url( $post->post_author );
	$author_name = get_the_author_meta( 'nicename', $post->post_author );
	_e( 'By', 'artistas' );

	?>
	<a href="<?php echo esc_url( $author_url ); ?>"><?php echo wp_kses_post( $author_name ); ?></a>
	<?php
}

function artistas_footer_post ( $settings, $comments = '', $share = '' ) {

	if ( empty( $settings ) ) {
		global $artistas_theme_options;

		$settings = $artistas_theme_options;
	}

	if ( ( empty( $comments ) || empty( $settings[ $comments ] ) || ! comments_open() ) &&
	     ( ( empty( $share ) || empty( $settings[ $share ] ) || ! shortcode_exists( 'kd_share_post' ) ) )
	) {
		return;
	}

	?>
	<div class="post-footer clearfix">
		<?php
		if ( ! empty( $comments ) && ! empty( $settings[ $comments ] ) ) {
			artistas_comments_count();
		}
		if ( ! empty( $share ) && ! empty( $settings[ $share ] ) ) {
			artistas_share_button();
		}
		?>
	</div>
	<?php

}

function artistas_comments_count () {
	?>
	<div class="comment-count">
		<a href="<?php comments_link(); ?>">
			<?php comments_number( esc_html__( ' No Comment', 'artistas' ), esc_html__( '1 Comment', 'artistas' ), '% ' . esc_html__( 'Comments', 'artistas' ) ); ?>
		</a>
	</div>
	<?php
}

function artistas_share_button () {
	?>
	<div class="post-share-wrap">
		<div class="post-share">
			<?php
			do_shortcode( '[kd_share_post]' );;
			?>
		</div>
	</div>
	<?php
}

function artistas_post_media () {

	if ( shortcode_exists( 'kd_formats_ui' ) ) {

		$data_post_format    = get_post_meta( get_the_ID(), 'kd_post_formats', true );
		$current_post_format = get_post_format();


		if ( ! empty( $data_post_format ) && ! empty( $data_post_format[ $current_post_format ] ) ) {
			$flag_media = 'do_shortcode';
			?>
			<!-- Post Media -->
			<div class="post-media">
				<?php do_shortcode( '[kd_formats_ui]' ); ?>
			</div>
			<!-- End Post Media -->
			<?php
		}
	}
	if ( empty( $flag_media ) ) {
		$image_thumbnail = artistas_get_image_thumbnail( 'artistas_1200x800' );

		if ( ! empty( $image_thumbnail ) ) {
			?>
			<div class="post-media">
				<img src="<?php echo esc_url( $image_thumbnail ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
			</div>
			<?php
		}
	}

}

function artistas_author_box ( $artistas_theme_options ) {
	global $artistas_socials_data;

	$author_id   = get_the_author_meta( 'ID' );
	$author_meta = get_user_meta( $author_id, 'artistas_user_meta', true );
	$avatar_url  = get_avatar_url( $author_id, array( 'size' => 300 ) );
	$author_name = get_the_author_meta( 'display_name' );
	$link_author = get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) );

	?>
	<!-- Post Author Box -->
	<div id="post-author">
		<div class="author-wrap clearfix">
			<div class="avatar-author" style="background-image: url(<?php echo esc_url( $avatar_url ); ?>)">
				<img src="<?php echo esc_url( $avatar_url ); ?>" alt="<?php echo esc_attr( $author_name ); ?>">
			</div>
			<div class="post-author-content">
				<div class="author-top">
					<div class="author-name">
						<h2 class="title">
							<a href="<?php echo esc_url( $link_author ); ?>">
								<?php echo esc_html( $author_name ); ?>
							</a>
						</h2>
					</div>
				</div>
				<div class="author-description">
					<?php the_author_meta( 'description' ); ?>
				</div>
			</div>
		</div>
		<div class="author-socials">
			<?php
			foreach ( $artistas_socials_data as $key => $social ) {
				if ( ! empty( $author_meta[ $key ] ) ) {
					?>
					<a href="<?php echo esc_url( $artistas_theme_options[ $key ] ) ?>" title="<?php echo esc_attr( $social['title'] ) ?>">
						<i class="<?php echo esc_attr( $social['class'] ) ?>"></i>
					</a>
					<?php
				}
			}
			?>
		</div>
	</div>
	<!-- End Post Author Box -->
	<?php
}

function artistas_comment_nav () {
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) {
		?>
		<nav class="navigation comment-navigation" role="navigation">
			<div class="nav-links clearfix">
				<?php
				$older_comments = esc_html__( 'Older Comments', 'artistas' );
				$newer_comments = esc_html__( 'Newer Comments', 'artistas' );
				if ( $prev_link = get_previous_comments_link( $older_comments ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( $newer_comments ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
				?>
			</div>
		</nav>
		<?php
	}
}

function artistas_callback_comments ( $comment, $args, $depth ) {

	$author_url  = $comment->comment_author_url;
	$before_html = $after_html = '';
	if ( empty( $author_url ) ) {
		$user = get_user_by( 'email', $comment->comment_author_email );
		if ( ! empty( $user ) ) {
			$author_url = $user->user_url;
		}
	}
	if ( ! empty( $author_url ) ) {
		$before_html = '<a href="' . esc_url( $author_url ) . '">';
		$after_html  = '</a>';
	}
	?>
	<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
		<div class="comment-body">
			<div class="comment-reply">
				<?php
				edit_comment_link( esc_html__( 'Edit', 'artistas' ), '', '' );
				comment_reply_link(
					array_merge( $args,
						array(
							'reply_text' => esc_html__( 'Reply', 'artistas' ),
							'after'      => '',
							'depth'      => $depth,
							'max_depth'  => $args['max_depth']
						)
					),
					$comment->comment_ID
				);
				?>
			</div>
			<div class="comment-avartar">
				<?php
				echo wp_kses_post( $before_html );
				echo get_avatar( $comment->comment_author_email, 70 );
				echo wp_kses_post( $after_html );
				?>
			</div>
			<div class="comment-context">
				<div class="comment-head">
					<h3 class="comment-author">
						<?php
						echo wp_kses_post( $before_html );
						echo wp_kses_post( $comment->comment_author );
						echo wp_kses_post( $after_html );
						?>
					</h3>
					<span class="comment-date"><?php echo get_comment_date(); ?></span>
				</div>
				<div class="comment-content">
					<?php
					if ( ! $comment->comment_approved ) {
						?>
						<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'artistas' ); ?></p>
						<?php
					} else {
						?>
						<p><?php comment_text(); ?></p>
						<?php
					}
					?>
				</div>
			</div>
		</div>
	</li>
	<?php
}

function artistas_custom_font_for_elements ( $custom_css ) {

	global $artistas_theme_options, $artistas_elements;
	foreach ( $artistas_elements as $key => $element ) {
		$custom_css .= artistas_custom_typography_for_element( $artistas_theme_options, $key . '_font', $element );
	}

	// Change Main Color for site
	$main_color = $artistas_theme_options['main_color'];

	if ( ! empty( $main_color ) && is_array( $main_color ) && ! empty( $main_color['hex'] ) && is_array( $main_color['hex'] ) ) {
		if ( is_array( $main_color ) ) {
			$main_color = $main_color['hex'];
		}
		$elements['color']            = array(
			'a:hover',
			'.current_page_item > a, .current-menu-ancestor > a, .current-menu-item > a, .current-menu-parent.menu-item-has-children > a',
			'.wrap-logo span',
			'.post.sticky:after',
			'.pagination li a:focus, .pagination li a:hover, .pagination li span:focus, .pagination li span.current, .pagination li span:hover',
			'.kd-navigation a:hover',
			'.archive-name',
			'#comments .comment-author a:hover, #respond .logged-in-as a:hover',
			'.nav-links a:hover',
			'.form-login-logout a',
			'.page_title_404 span'

		);
		$elements['background-color'] = array(
			'::-moz-selection',
			'mark, .mark',
			'.post-cat a',
			'.post-password-form input[type=submit]',
			'.read-more:hover',
			'#comments .comment-reply a:hover',
			'.form-submit input[type="submit"]:hover',
			'.form-submit input',
			'.go-to-home a',
			'.widget-title:before',
			'.widget_search .search-submit',
			array(
				'before' => '@keyframes loaderBlock {' . PHP_EOL . '55% {',
				'after'  => '} ' . PHP_EOL . ' }'
			),
			array(
				'before' => '@keyframes loaderBlockInverse {' . PHP_EOL . '55% {',
				'after'  => '} ' . PHP_EOL . ' }'
			),
			'.kd-wrap-shortcode .owl-page.active'

		);
		$elements['border-color']     = array(
			'.widget-title, .widget .title',
			'.kd-wrap-shortcode .owl-page'
		);

		foreach ( $elements as $type => $lists ) {


			foreach ( $lists as $element ) {
				$before = $after = PHP_EOL;
				if ( is_array( $element ) ) {
					$before .= $element['before'];
					$after  .= $element['after'];
				} else {
					$before .= $element . ' { ' . PHP_EOL;
					$after  .= ' } ';
				}

				$custom_css .= $before . $type . ' : ' . $main_color . '; ' . $after;

			}
		}
		if ( ! empty( $artistas_theme_options['main_color']['rgba'] ) ) {
			$custom_css .= PHP_EOL . ' .btn-back-to-top { ' . PHP_EOL . 'background-color: rgba(' . $artistas_theme_options['main_color']['rgba'] . ', 0.7); }';
		}
	}


	return $custom_css;

}

function artistas_custom_typography_for_element ( $artistas_theme_options, $settings = '', $element = '' ) {

	if ( empty( $element ) || empty( $settings ) ) {
		return;
	}

	if ( empty( $artistas_theme_options[ $settings ] ) || ! is_array( $artistas_theme_options[ $settings ] ) ) {
		return;
	}
	$settings   = $artistas_theme_options[ $settings ];
	$excerpt    = array( 'google' );
	$custom_css = PHP_EOL . $element . ' { ';
	foreach ( $settings as $key => $setting ) {
		if ( in_array( $key, $excerpt ) ) {
			continue;
		}
		if ( ! empty( $setting ) ) {
			$custom_css .= $key . ' : ' . $setting . '; ' . PHP_EOL;
		}
	}
	$custom_css .= ' } ';

	return $custom_css;
}